# sdtg-lib
Second-dimensional Telegram Games library.
## Requires:
`pyTelegramBotApi`
## Installing by requirements.txt:
``sdtg``
## Installing by pip:
``$ pip3 install sdtg``
## Usage:
See examples for all details.

